@@ -38,6 +38,7 @@ ABBR_WORDS = {
         r"\bp\.m\.": "pm",
         r"\bmr[\. ]": "mister",
         r"\bmrs[\. ]": "missus",
+        r"\bms[\. ]": "mizz",
         r"\bdr[\. ]": "doctor",
         r"\bprof[\. ]": "professor",
         r"\bcapt[\. ]": "captain",
@@ -54,9 +55,23 @@ ABBR_WORDS = {
         r"\bz\.B\. ": "zum Beispiel",
         r"\bbzw\.": "beziehungsweise",
         r"\busw\.": "und so weiter",
+        r"\betw\.": "etwas",
+        r"\bBhf\.": "Bahnhof",
+        r"\bHbf\.": "Hauptbahnhof",
+        r"\bNr\.": "Nummer",
+        r"\bStr\.": "Straße",
+        r"\bca\.": "circa",
+        r"\bDr\.": "Doktor",
+        r"\bTel\.": "Telefon",
+        r"\bMwSt\.": "Mehrwertsteuer",
+        r"\bMWSt\.": "Mehrwertsteuer",
+        r"\bPLZ\b": "Postleitzahl",
+        r"\bNK\b": "Nebenkosten",
     },
 }
 
+ABBR_SEARCH_FLAG = {"en": re.IGNORECASE, "de": 0}
+
 
 class BaseFormatter:
     def __init__(self, lang="en"):
@@ -193,10 +208,11 @@ class TextFormatter(BaseFormatter):
 
         # handle dot and abbr words first
         # so it not confuses with period and illegal dots
+        search_flag = ABBR_SEARCH_FLAG[self.lang]
         for abbr, repl in ABBR_WORDS[self.lang].items():
-            for found in re.findall(abbr, text, flags=re.IGNORECASE):
+            for found in re.findall(abbr, text, flags=search_flag):
                 change_list[found] = repl.upper() if self.return_upper_case else repl
-            text = re.sub(abbr, repl + " ", text, flags=re.IGNORECASE)
+            text = re.sub(abbr, repl + " ", text, flags=search_flag)
 
         text = text.replace(".", " ")
 
